import { ParserOptions as CronExpressionParserOptions } from 'cron-parser';
import { OnError } from './OnError';
import { OnInfo } from './OnInfo';
export declare const CODE_CRON_TASK_STARTED = "cronTaskStarted";
export declare const CODE_CRON_TASK_FINISHED = "cronTaskFinished";
export declare const CODE_CRON_TASK_SCHEDULED = "cronTaskScheduled";
export declare const CODE_CRON_TASK_FAILED = "cronTaskFailed";
export declare type TaskFunction = () => Promise<unknown> | void;
export declare type ScalarInterval = number | string;
export declare type StaticInterval = ScalarInterval | Date;
export declare type IntervalFunction = () => StaticInterval | Promise<StaticInterval>;
export declare type Interval = ScalarInterval | IntervalFunction;
export declare type TaskId = string;
export interface CronTaskCaller {
    <T>(task: () => Promise<T>): Promise<T> | T;
}
export declare function runCronTask(taskId: TaskId): Promise<void>;
export declare type InitOptions = {
    runCronTasks: boolean;
    cronExpressionParserOptions: CronExpressionParserOptions;
    onError: OnError;
    onInfo: OnInfo;
    cronTaskCaller: CronTaskCaller;
};
export declare function init({ runCronTasks, cronExpressionParserOptions, onError, onInfo, cronTaskCaller }: InitOptions): void;
export declare function stopCronTasks(): void;
export declare function startCronTasks(): void;
export declare function scheduleCronTaskImmediately(taskId: TaskId): Promise<void>;
export declare function cronTask(taskId: TaskId, interval: Interval, task: TaskFunction): Promise<void>;
